@@ -13,8 +13,12 @@ pub struct TlsConfig {
     pub cert_path: String,
     pub key_path: String,
     pub ca_path: String,
+    pub client_cert_path: String,
+    pub client_key_path: String,
+    pub client_ca_path: String,
     pub mode: String,
-    pub socket_addr: std::net::SocketAddr,
+    pub socket_addr: Option<std::net::SocketAddr>,
+    pub server_endpoint: String,
     // https://docs.rs/rustls/latest/rustls/struct.ServerConfig.html
     pub server_config: ServerConfig,
 }
@@ -30,14 +34,22 @@ impl TlsConfig {
     pub fn show(&self) -> bool {
         println!("\
             enabled={} \
+            server_endpoint={} \
             cert={} \
             key={} \
             ca={} \
+            client_cert={} \
+            client_key={} \
+            client_ca={} \
             mode={}",
                 self.enabled,
+                self.server_endpoint,
                 self.cert_path,
                 self.key_path,
                 self.ca_path,
+                self.client_cert_path,
+                self.client_key_path,
+                self.client_ca_path,
                 self.mode);
         return true;
     }
